@@ -81,8 +81,8 @@ enum
 {
   NOTEBOOK_PAGE_GENERAL,
   NOTEBOOK_PAGE_EMBLEMS,
-  NOTEBOOK_PAGE_PERMISSIONS,
-  NOTEBOOK_PAGE_HIGHLIGHT
+  NOTEBOOK_PAGE_HIGHLIGHT,
+  NOTEBOOK_PAGE_PERMISSIONS
 };
 
 
@@ -707,18 +707,6 @@ thunar_properties_dialog_init (ThunarPropertiesDialog *dialog)
   gtk_widget_show (chooser);
   gtk_widget_show (label);
 
-  /*
-     Permissions chooser
-   */
-  label = gtk_label_new (_("Permissions"));
-  dialog->permissions_chooser = thunar_permissions_chooser_new ();
-  g_object_bind_property (G_OBJECT (dialog),                      "files",
-                          G_OBJECT (dialog->permissions_chooser), "files",
-                          G_BINDING_SYNC_CREATE);
-  gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook), dialog->permissions_chooser, label);
-  gtk_widget_show (dialog->permissions_chooser);
-  gtk_widget_show (label);
-
   /*
      Highlight Color Chooser
    */
@@ -852,6 +840,18 @@ thunar_properties_dialog_init (ThunarPropertiesDialog *dialog)
                             G_CALLBACK (thunar_properties_dialog_color_editor_close), dialog);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   gtk_widget_show (button);
+
+  /*
+     Permissions chooser
+   */
+  label = gtk_label_new (_("Permissions"));
+  dialog->permissions_chooser = thunar_permissions_chooser_new ();
+  g_object_bind_property (G_OBJECT (dialog),                      "files",
+                          G_OBJECT (dialog->permissions_chooser), "files",
+                          G_BINDING_SYNC_CREATE);
+  gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook), dialog->permissions_chooser, label);
+  gtk_widget_show (dialog->permissions_chooser);
+  gtk_widget_show (label);
 }
 
 
@@ -1243,8 +1243,7 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
   /* check if the icon may be changed (only for writable .desktop files) */
   g_object_ref (G_OBJECT (dialog->icon_image));
   gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (dialog->icon_image)), dialog->icon_image);
-  if (thunar_file_is_writable (file)
-      && thunar_file_is_desktop_file (file, NULL))
+  if (thunar_file_is_writable (file) && thunar_file_is_desktop_file (file))
     {
       gtk_container_add (GTK_CONTAINER (dialog->icon_button), dialog->icon_image);
       gtk_widget_show (dialog->icon_button);
@@ -1295,7 +1294,7 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
     }
 
   /* update the application chooser (shown only for non-executable regular files!) */
-  show_chooser = thunar_file_is_regular (file) && !thunar_file_is_executable (file);
+  show_chooser = thunar_file_is_regular (file) && !thunar_file_can_execute (file);
   gtk_widget_set_visible (dialog->openwith_chooser, show_chooser);
   if (show_chooser)
     thunar_chooser_button_set_file (THUNAR_CHOOSER_BUTTON (dialog->openwith_chooser), file);
