@@ -49,6 +49,8 @@ typedef enum
   THUNAR_WINDOW_ACTION_CLOSE_WINDOW,
   THUNAR_WINDOW_ACTION_CLOSE_ALL_WINDOWS,
   THUNAR_WINDOW_ACTION_EDIT_MENU,
+  THUNAR_WINDOW_ACTION_UNDO,
+  THUNAR_WINDOW_ACTION_REDO,
   THUNAR_WINDOW_ACTION_PREFERENCES,
   THUNAR_WINDOW_ACTION_VIEW_MENU,
   THUNAR_WINDOW_ACTION_RELOAD,
@@ -61,6 +63,7 @@ typedef enum
   THUNAR_WINDOW_ACTION_VIEW_SIDE_PANE_SHORTCUTS,
   THUNAR_WINDOW_ACTION_VIEW_SIDE_PANE_TREE,
   THUNAR_WINDOW_ACTION_TOGGLE_SIDE_PANE,
+  THUNAR_WINDOW_ACTION_TOGGLE_IMAGE_PREVIEW,
   THUNAR_WINDOW_ACTION_VIEW_STATUSBAR,
   THUNAR_WINDOW_ACTION_VIEW_MENUBAR,
   THUNAR_WINDOW_ACTION_CONFIGURE_TOOLBAR,
@@ -99,6 +102,7 @@ typedef enum
   THUNAR_WINDOW_ACTION_SWITCH_NEXT_TAB,
   THUNAR_WINDOW_ACTION_SEARCH,
   THUNAR_WINDOW_ACTION_CANCEL_SEARCH,
+  THUNAR_WINDOW_ACTION_SHOW_HIGHLIGHT,
 
   THUNAR_WINDOW_N_ACTIONS
 } ThunarWindowAction;
@@ -107,12 +111,6 @@ GType                     thunar_window_get_type                            (voi
 ThunarFile               *thunar_window_get_current_directory               (ThunarWindow        *window);
 void                      thunar_window_set_current_directory               (ThunarWindow        *window,
                                                                              ThunarFile          *current_directory);
-void                      thunar_window_scroll_to_file                      (ThunarWindow        *window,
-                                                                             ThunarFile          *file,
-                                                                             gboolean             select,
-                                                                             gboolean             use_align,
-                                                                             gfloat               row_align,
-                                                                             gfloat               col_align);
 GList                    *thunar_window_get_directories                     (ThunarWindow        *window,
                                                                              gint                *active_page);
 gboolean                  thunar_window_set_directories                     (ThunarWindow        *window,
